@@ -4,6 +4,7 @@ import warnings
 from decimal import Decimal
 from braintree.add_on import AddOn
 from braintree.disbursement_detail import DisbursementDetail
+from braintree.dispute import Dispute
 from braintree.discount import Discount
 from braintree.successful_result import SuccessfulResult
 from braintree.status_event import StatusEvent
@@ -87,7 +88,8 @@ class Transaction(Resource):
         """
 
         FullInformation = "full_information"
-        Token = "token"
+        Token           = "token"
+        Unrecognized    = "unrecognized"
 
     class GatewayRejectionReason(object):
         """
@@ -98,15 +100,18 @@ class Transaction(Resource):
         * braintree.Transaction.GatewayRejectionReason.Cvv
         * braintree.Transaction.GatewayRejectionReason.Duplicate
         """
-        Avs = "avs"
-        AvsAndCvv = "avs_and_cvv"
-        Cvv = "cvv"
-        Duplicate = "duplicate"
+        Avs          = "avs"
+        AvsAndCvv    = "avs_and_cvv"
+        Cvv          = "cvv"
+        Duplicate    = "duplicate"
+        Fraud        = "fraud"
+        Unrecognized = "unrecognized"
 
     class Source(object):
-        Api = "api"
+        Api          = "api"
         ControlPanel = "control_panel"
-        Recurring = "recurring"
+        Recurring    = "recurring"
+        Unrecognized = "unrecognized"
 
     class EscrowStatus(object):
         """
@@ -124,6 +129,7 @@ class Transaction(Resource):
         ReleasePending = "release_pending"
         Released       = "released"
         Refunded       = "refunded"
+        Unrecognized   = "unrecognized"
 
     class Status(object):
         """
@@ -152,6 +158,7 @@ class Transaction(Resource):
         Settling               = "settling"
         SubmittedForSettlement = "submitted_for_settlement"
         Voided                 = "voided"
+        Unrecognized           = "unrecognized"
 
     class Type(object):
         """
@@ -392,9 +399,9 @@ class Transaction(Resource):
     @staticmethod
     def create_signature():
         return [
-            "amount", "customer_id", "device_session_id", "merchant_account_id", "order_id", "channel",
+            "amount", "customer_id", "device_session_id", "fraud_merchant_id", "merchant_account_id", "order_id", "channel",
             "payment_method_token", "purchase_order_number", "recurring", "shipping_address_id",
-            "device_data",
+            "device_data", "billing_address_id",
             "tax_amount", "tax_exempt", "type", "venmo_sdk_payment_method_code", "service_fee_amount",
             {
                 "credit_card": [
@@ -467,6 +474,8 @@ class Transaction(Resource):
             self.descriptor = Descriptor(gateway, attributes.pop("descriptor"))
         if "disbursement_details" in attributes:
             self.disbursement_details = DisbursementDetail(attributes.pop("disbursement_details"))
+        if "disputes" in attributes:
+            self.disputes = [Dispute(dispute) for dispute in self.disputes]
 
     @property
     def refund_id(self):
